
/*
 * Copyright (C) JOSH Development Team
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2, as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License version 2 for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Please visit www.joshvm.org if you need additional information or
 * have any questions.
 */
import java.io.IOException;

import org.joshvm.ui.Color;
import org.joshvm.ui.Container;
import org.joshvm.ui.Display;
import org.joshvm.ui.Screen;
import org.joshvm.ui.UIObject;
import org.joshvm.ui.layout.Flex;
import org.joshvm.ui.listener.ClickedListener;
import org.joshvm.ui.listener.ValueChangedListener;
import org.joshvm.ui.widget.Button;
import org.joshvm.ui.widget.CheckBox;
import org.joshvm.ui.widget.DropdownList;
import org.joshvm.ui.widget.Image;
import org.joshvm.ui.widget.Label;
import org.joshvm.ui.widget.Roller;
import org.joshvm.ui.widget.Slider;
import org.joshvm.ui.widget.Switch;
import org.joshvm.ui.widget.Table;
import org.joshvm.ui.widget.Textarea;

public class UIDemoB {
    private Display display = Display.getDisplay();

    private void setBtnValue(Button btn, int value) {
        btn.setText("Button" + value);
    }

    private void onSwitchCheckedChanged(Switch sw, Image img) {
        if (sw.isChecked()) {
            try {
                img.setSource("/package.png");
            } catch (IOException e) {
            }
        } else {
            img.clear();
        }
    }

    private void onSliderValueChanged(Slider s, Label label) {
        label.setText("Value:" + s.getValue());
    }

    private void run() {
        Screen screen = new Screen();
        Container container = screen;

        // button
        Button btn = new Button();
        btn.setPos(50, 100);
        btn.setUserData(new Integer(0));
        setBtnValue(btn, 0);
        btn.setClickedListener(new ClickedListener() {
            public void onClicked(UIObject target) {
                Button b = (Button) target;
                int count = ((Integer) b.getUserData()).intValue();
                count++;
                if (count >= 10) {
                    count = 0;
                }
                b.setUserData(new Integer(count));
                Color color = Color.GREEN;
                if (count % 3 == 0) {
                    color = Color.BLUE;
                } else if (count % 3 == 1) {
                    color = Color.RED;
                }
                setBtnValue(b, count);
                b.setBackgroundColor(color);
            }
        });
        container.addWidget(btn);

        // roller
        Roller roller = new Roller();
        roller.setPos(150, 100);
        roller.addOption("First");
        roller.addOption("Second");
        roller.addOption("Third");
        roller.addOption("Fourth");
        roller.addOption("Fifth");
        roller.addOption("Sixth");
        roller.addOption("Seventh");
        roller.setSelected(5);
        container.addWidget(roller);

        // table
        Table tb = new Table(2, 3);
        tb.setPos(100, 200);
        tb.setColumnWidth(1, 50);
        tb.setCellText(0, 0, "C00");
        tb.setCellText(1, 0, "C10");
        tb.setCellText(0, 1, "C01");
        tb.setCellText(1, 1, "C11");
        tb.setCellText(0, 2, "C02");
        tb.setCellText(1, 2, "C12");
        tb.setTextAlign(UIObject.ALIGN_CENTER);
        container.addWidget(tb);

        // image
        final Image img = new Image();
        img.setSize(100, 100);
        container.addWidget(img);

        // switch
        Switch sw = new Switch();
        sw.setValueChangedListener(new ValueChangedListener() {
            public void onValueChanged(UIObject target) {
                onSwitchCheckedChanged((Switch) target, img);
            }
        });
        sw.setChecked(true);
        onSwitchCheckedChanged(sw, img);
        container.addWidget(sw);

        // drop
        DropdownList dropdown = new DropdownList();
        dropdown.setPos(200, 100);
        dropdown.addOption("A");
        dropdown.addOption("B");
        dropdown.addOption("C");
        dropdown.addOption("D");
        dropdown.addOption("E");
        dropdown.addOption("F");
        dropdown.addOption("G");
        container.addWidget(dropdown);

        Container subC = new Container();
        subC.setBorderWidth(0);
        subC.setSize(150, 200);
        // label
        final Label label = new Label();
        label.setText("Value:");
        label.setBackgroundColor(Color.GREEN);
        label.setAlign(UIObject.ALIGN_LEFT, UIObject.ALIGN_CENTER);
        subC.addWidget(label);

        // slider
        Slider slider = new Slider();
        slider.setSize(15, 150);
        slider.setBackgroundColor(new Color(0xFFFF0000));
        slider.setValueChangedListener(new ValueChangedListener() {
            public void onValueChanged(UIObject target) {
                onSliderValueChanged((Slider) target, label);
            }
        });
        slider.setValue(40);
        onSliderValueChanged(slider, label);
        slider.setAlign(UIObject.ALIGN_RIGHT, UIObject.ALIGN_CENTER);
        subC.addWidget(slider);
        container.addContainer(subC);

        // textarea
        final Textarea ta = new Textarea();
        ta.setText("This is a textarea.");
        container.addWidget(ta);

        // checkbox
        CheckBox cb = new CheckBox();
        cb.setText("Password Mode");
        container.addWidget(cb);
        cb.setValueChangedListener(new ValueChangedListener() {
            public void onValueChanged(final UIObject target) {
                CheckBox cb = (CheckBox) target;
                if (cb.isChecked()) {
                    ta.enableMode(Textarea.MODE_PASSWORD);
                } else {
                    ta.disableMode(Textarea.MODE_PASSWORD);
                }
            }
        });

        Flex layout = new Flex();
        layout.setFlowType(Flex.FLEX_FLOW_TYPE_ROW_WRAP);
        layout.setMainAlign(Flex.FLEX_ALIGN_SPACE_EVENLY);
        layout.setCrossAlign(Flex.FLEX_ALIGN_CENTER);
        layout.setTrackCrossAlign(Flex.FLEX_ALIGN_SPACE_EVENLY);
        container.updateLayout(layout);

        display.setScreen(screen);
    }

    private void stop() {
        display.stop();
    }

    public static void main(String[] args) {
        UIDemoB demo = new UIDemoB();
        System.out.println("===start===");
        demo.run();
        try {
            Thread.sleep(60000);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        System.out.println("===stop===");
        demo.stop();
    }
}
